@@ -7,36 +7,15 @@ import (
 	"strings"
 
 	"github.com/jackc/pgx/v5"
-	"github.com/turbot/steampipe/pkg/connection_state"
+	"github.com/turbot/steampipe-plugin-sdk/v5/sperr"
 	"github.com/turbot/steampipe/pkg/constants"
 	"github.com/turbot/steampipe/pkg/db/db_common"
+	"github.com/turbot/steampipe/pkg/introspection"
+	"github.com/turbot/steampipe/pkg/statushooks"
 	"github.com/turbot/steampipe/pkg/steampipeconfig"
 	"github.com/turbot/steampipe/pkg/utils"
-	"github.com/turbot/steampipe/sperr"
 )
 
-//// dropLegacySchemas drops the legacy 'steampipe_command' schema if it exists
-//// and the 'internal' schema if it contains only the 'glob' function
-//// and maybe the 'connection_state' table
-//func dropLegacySchemas(ctx context.Context, conn *pgx.Conn) error {
-//	utils.LogTime("db_local.dropLegacySchema start")
-//	defer utils.LogTime("db_local.dropLegacySchema end")
-//
-//	return error_helpers.CombineErrors(
-//		dropLegacyInternalSchema(ctx, conn),
-//		dropLegacySteampipeCommandSchema(ctx, conn),
-//	)
-//}
-//
-//// dropLegacySteampipeCommandSchema drops the 'steampipe_command' schema if it exists
-//func dropLegacySteampipeCommandSchema(ctx context.Context, conn *pgx.Conn) error {
-//	utils.LogTime("db_local.dropLegacySteampipeCommand start")
-//	defer utils.LogTime("db_local.dropLegacySteampipeCommand end")
-//
-//	_, err := conn.Exec(ctx, fmt.Sprintf("DROP SCHEMA IF EXISTS %s CASCADE", constants.LegacyCommandSchema))
-//	return err
-//}
-
 // dropLegacyInternalSchema looks for a schema named 'internal'
 // which has a function called 'glob' and maybe a table named 'connection_state'
 // and drops it
@@ -119,8 +98,8 @@ INNER JOIN
 		"glob": true,
 	}
 	expectedTables := map[string]bool{
-		"connection_state":             true, // legacy table name
-		constants.ConnectionStateTable: true,
+		"connection_state":                   true, // previous legacy table name
+		constants.LegacyConnectionStateTable: true,
 	}
 
 	for _, f := range functions {
@@ -141,6 +120,18 @@ INNER JOIN
 }
 
 func setupInternal(ctx context.Context, conn *pgx.Conn) error {
+	statushooks.SetStatus(ctx, "Dropping legacy schema")
+	if err := dropLegacyInternalSchema(ctx, conn); err != nil {
+		// do not fail
+		// worst case scenario is that we have a couple of extra schema
+		// these won't be in the search path anyway
+		log.Println("[INFO] failed to drop legacy 'internal' schema", err)
+	}
+
+	// setup internal schema
+	// this includes setting the state of all connections in the connection_state table to pending
+	statushooks.SetStatus(ctx, "Setting up internal schema")
+
 	utils.LogTime("db_local.setupInternal start")
 	defer utils.LogTime("db_local.setupInternal end")
 
@@ -207,46 +198,69 @@ func validateFunction(f db_common.SQLFunction) error {
 	return nil
 }
 
+/*
+	to initialize the connection state table:
+
+- load existing connection state (ignoring relation not found error)
+- delete and recreate the table
+- update status of existing connection state to pending or imncomplete as appropriate
+- write back connection state
+*/
 func initializeConnectionStateTable(ctx context.Context, conn *pgx.Conn) error {
-
-	createQueries := []db_common.QueryWithArgs{
-		connection_state.GetConnectionStateTableCreateSql(),
-		connection_state.GetConnectionStateTableGrantSql(),
-	}
-
-	// apply any alterations
-	// this is for changes which are applied to the table after v0.20.0
-	createQueries = append(createQueries, connection_state.GetConnectionStateTableColumnAlterSql()...)
-
-	if _, err := ExecuteSqlWithArgsInTransaction(ctx, conn, createQueries...); err != nil {
-		return err
-	}
-
-	// now load the state
+	// load the state (if the table is there)
 	connectionStateMap, err := steampipeconfig.LoadConnectionState(ctx, conn)
 	if err != nil {
-		return err
-	}
+		// ignore relation not found error
+		if !db_common.IsRelationNotFoundError(err) {
+			return err
+		}
 
+		// create an empty connectionStateMap
+		connectionStateMap = steampipeconfig.ConnectionStateMap{}
+	}
 	// if any connections are in a ready  state, set them to pending - we need to run refresh connections before we know this connection is still valid
-	pendingSql := connection_state.GetReadConnectionStatePendingSql()
 	// if any connections are not in a ready or error state, set them to pending_incomplete
-	incompleteErrorSql := connection_state.GetIncompleteConnectionStatePendingIncompleteSql()
-	queries := []db_common.QueryWithArgs{
-		incompleteErrorSql,
-		pendingSql,
+	connectionStateMap.SetConnectionsToPendingOrIncomplete()
+
+	// migration: ensure filename and line numbers are set for all connection states
+	connectionStateMap.PopulateFilename()
+
+	// drop the table and recreate
+	queries := introspection.GetConnectionStateTableDropSql()
+	queries = append(queries, introspection.GetConnectionStateTableCreateSql()...)
+	queries = append(queries, introspection.GetConnectionStateTableGrantSql()...)
+
+	// add insert queries for all connection state
+	for _, s := range connectionStateMap {
+		queries = append(queries, introspection.GetUpsertConnectionStateSql(s)...)
 	}
 
-	// for any connection in the connection config but not in the connection state table,
-	// add an entry with `pending_incomplete` state this is to work around the race condition
-	// where we wait for connection state before RefreshConnections has added
-	// any new connections into the state table
+	// for any connection in the connection config but NOT in the connection state table,
+	// add an entry with `pending_incomplete` state this is to work around the race condition where
+	// we wait for connection state before RefreshConnections has added any new connections into the state table
 	for connection, connectionConfig := range steampipeconfig.GlobalConfig.Connections {
 		if _, ok := connectionStateMap[connection]; !ok {
-			queries = append(queries, connection_state.GetNewConnectionStateTableInsertSql(connectionConfig))
+			queries = append(queries, introspection.GetNewConnectionStateFromConnectionInsertSql(connectionConfig)...)
 		}
 	}
-
 	_, err = ExecuteSqlWithArgsInTransaction(ctx, conn, queries...)
 	return err
 }
+
+func PopulatePluginTable(ctx context.Context, conn *pgx.Conn) error {
+	plugins := steampipeconfig.GlobalConfig.PluginsInstances
+
+	// drop the table and recreate
+	queries := []db_common.QueryWithArgs{
+		introspection.GetPluginTableDropSql(),
+		introspection.GetPluginTableCreateSql(),
+		introspection.GetPluginTableGrantSql(),
+	}
+
+	// add insert queries for all connection state
+	for _, p := range plugins {
+		queries = append(queries, introspection.GetPluginTablePopulateSql(p))
+	}
+	_, err := ExecuteSqlWithArgsInTransaction(ctx, conn, queries...)
+	return err
+}
