@@ -7,6 +7,7 @@ import (
 
 	"github.com/google/uuid"
 	filehelpers "github.com/turbot/go-kit/files"
+	"github.com/turbot/steampipe/pkg/filepaths"
 	"github.com/turbot/steampipe/pkg/utils"
 )
 
@@ -17,21 +18,21 @@ type Passwords struct {
 }
 
 func writePasswordFile(password string) error {
-	return os.WriteFile(getPasswordFileLocation(), []byte(password), 0600)
+	return os.WriteFile(filepaths.GetPasswordFileLocation(), []byte(password), 0600)
 }
 
 // readPasswordFile reads the password file and returns it contents.
 // the the password file could not be found, then it generates a new
 // password and writes it to the password file, before returning it
 func readPasswordFile() (string, error) {
-	if !filehelpers.FileExists(getPasswordFileLocation()) {
+	if !filehelpers.FileExists(filepaths.GetPasswordFileLocation()) {
 		p := generatePassword()
 		if err := writePasswordFile(p); err != nil {
 			return "", err
 		}
 		return p, nil
 	}
-	contentBytes, err := os.ReadFile(getPasswordFileLocation())
+	contentBytes, err := os.ReadFile(filepaths.GetPasswordFileLocation())
 	if err != nil {
 		return "", err
 	}
@@ -54,19 +55,19 @@ func generatePassword() string {
 func migrateLegacyPasswordFile() error {
 	utils.LogTime("db_local.migrateLegacyPasswordFile start")
 	defer utils.LogTime("db_local.migrateLegacyPasswordFile end")
-	if filehelpers.FileExists(getLegacyPasswordFileLocation()) {
+	if filehelpers.FileExists(filepaths.GetLegacyPasswordFileLocation()) {
 		p, err := getLegacyPasswords()
 		if err != nil {
 			return err
 		}
-		os.Remove(getLegacyPasswordFileLocation())
+		os.Remove(filepaths.GetLegacyPasswordFileLocation())
 		return writePasswordFile(p.Steampipe)
 	}
 	return nil
 }
 
 func getLegacyPasswords() (*Passwords, error) {
-	contentBytes, err := os.ReadFile(getLegacyPasswordFileLocation())
+	contentBytes, err := os.ReadFile(filepaths.GetLegacyPasswordFileLocation())
 	if err != nil {
 		return nil, err
 	}
