@@ -12,7 +12,8 @@ import (
 
 // Constants for Config
 const (
-	DefaultInstallDir = "~/.steampipe"
+	DefaultInstallDir      = "~/.steampipe"
+	DefaultPipesInstallDir = "~/.pipes"
 
 	connectionsStateFileName     = "connection.json"
 	versionFileName              = "versions.json"
@@ -23,6 +24,7 @@ const (
 	legacyStateFileName          = "update-check.json"
 	availableVersionsFileName    = "available_versions.json"
 	legacyNotificationsFileName  = "notifications.json"
+	localPluginFolder            = "local"
 )
 
 var SteampipeDir string
@@ -55,6 +57,28 @@ func EnsurePluginDir() string {
 	return ensureSteampipeSubDir("plugins")
 }
 
+func EnsurePluginInstallDir(pluginImageDisplayRef  string) string {
+	installDir := PluginInstallDir(pluginImageDisplayRef)
+
+	if _, err := os.Stat(installDir); os.IsNotExist(err) {
+		err = os.MkdirAll(installDir, 0755)
+		error_helpers.FailOnErrorWithMessage(err, "could not create plugin install directory")
+	}
+
+	return installDir
+}
+
+func PluginInstallDir(pluginImageDisplayRef  string) string {
+	osSafePath := filepath.FromSlash(pluginImageDisplayRef )
+
+	fullPath := filepath.Join(EnsurePluginDir(), osSafePath)
+	return fullPath
+}
+
+func PluginBinaryPath(pluginImageDisplayRef, pluginAlias  string) string {
+	return filepath.Join(PluginInstallDir(pluginImageDisplayRef), PluginAliasToLongName(pluginAlias)+".plugin")
+}
+
 // EnsureConfigDir returns the path to the config directory (creates if missing)
 func EnsureConfigDir() string {
 	return ensureSteampipeSubDir("config")
@@ -143,6 +167,11 @@ func PluginVersionFilePath() string {
 	return filepath.Join(EnsurePluginDir(), versionFileName)
 }
 
+// LocalPluginPath returns the path to locally installed plugins
+func LocalPluginPath() string {
+	return filepath.Join(EnsurePluginDir(), localPluginFolder)
+}
+
 // DatabaseVersionFilePath returns the plugin version file path
 func DatabaseVersionFilePath() string {
 	return filepath.Join(EnsureDatabaseDir(), versionFileName)
