@@ -4,7 +4,6 @@ import (
 	"bytes"
 	"context"
 	"fmt"
-	"github.com/turbot/go-kit/hcl_helpers"
 	"log"
 	"os"
 	"path/filepath"
@@ -15,11 +14,13 @@ import (
 	"github.com/hashicorp/hcl/v2"
 	filehelpers "github.com/turbot/go-kit/files"
 	"github.com/turbot/go-kit/helpers"
+	"github.com/turbot/pipe-fittings/hclhelpers"
 	"github.com/turbot/steampipe-plugin-sdk/v5/sperr"
 	"github.com/turbot/steampipe/pkg/constants"
 	"github.com/turbot/steampipe/pkg/db/db_common"
 	"github.com/turbot/steampipe/pkg/error_helpers"
 	"github.com/turbot/steampipe/pkg/filepaths"
+	"github.com/turbot/steampipe/pkg/ociinstaller/versionfile"
 	"github.com/turbot/steampipe/pkg/steampipeconfig/modconfig"
 	"github.com/turbot/steampipe/pkg/steampipeconfig/options"
 	"github.com/turbot/steampipe/pkg/steampipeconfig/parse"
@@ -131,6 +132,19 @@ func loadSteampipeConfig(ctx context.Context, modLocation string, commandName st
 
 	steampipeConfig = NewSteampipeConfig(commandName)
 
+	// load plugin versions
+	v, err := versionfile.LoadPluginVersionFile(ctx)
+	if err != nil {
+		return nil, error_helpers.NewErrorsAndWarning(err)
+	}
+
+	// add any "local" plugins (i.e. plugins installed under the 'local' folder) into the version file
+	ew := v.AddLocalPlugins(ctx)
+	if ew != nil && ew.GetError() != nil {
+		return nil, ew
+	}
+	steampipeConfig.PluginVersions = v.Plugins
+
 	// load config from the installation folder -  load all spc files from config directory
 	include := filehelpers.InclusionsFromExtensions(constants.ConnectionConfigExtensions)
 	loadOptions := &loadConfigOptions{include: include}
@@ -259,7 +273,7 @@ func loadConfig(ctx context.Context, configFolder string, steampipeConfig *Steam
 			}
 			// add plugin to steampipeConfig
 			// NOTE: this errors if there is a plugin block with a duplicate label
-			if err := steampipeConfig.addPlugin(plugin, block); err != nil {
+			if err := steampipeConfig.addPlugin(plugin); err != nil {
 				return error_helpers.NewErrorsAndWarning(err)
 			}
 
@@ -303,7 +317,7 @@ func loadConfig(ctx context.Context, configFolder string, steampipeConfig *Steam
 					diags = append(diags, &hcl.Diagnostic{
 						Severity: hcl.DiagWarning,
 						Summary:  warning,
-						Subject:  hcl_helpers.BlockRangePointer(block),
+						Subject:  hclhelpers.BlockRangePointer(block),
 					})
 				}
 			}
