@@ -18,6 +18,15 @@ func (l *DashboardNodeList) Merge(other DashboardNodeList) {
 	}
 }
 
+func (l *DashboardNodeList) Get(name string) *DashboardNode {
+	for _, n := range *l {
+		if n.Name() == name {
+			return n
+		}
+	}
+	return nil
+}
+
 func (l *DashboardNodeList) Names() []string {
 	res := make([]string, len(*l))
 	for i, n := range *l {
@@ -25,3 +34,12 @@ func (l *DashboardNodeList) Names() []string {
 	}
 	return res
 }
+
+func (l *DashboardNodeList) Contains(other *DashboardNode) bool {
+	for _, e := range *l {
+		if e == other {
+			return true
+		}
+	}
+	return false
+}
