@@ -2,11 +2,11 @@ package modconfig
 
 import (
 	"fmt"
-	"github.com/turbot/go-kit/hcl_helpers"
 	"sort"
 
 	"github.com/Masterminds/semver/v3"
 	"github.com/hashicorp/hcl/v2"
+	"github.com/turbot/pipe-fittings/hclhelpers"
 	"github.com/turbot/steampipe-plugin-sdk/v5/sperr"
 	"github.com/turbot/steampipe/pkg/ociinstaller"
 	"github.com/turbot/steampipe/pkg/version"
@@ -62,10 +62,10 @@ func (r *Require) initialise(modBlock *hcl.Block) hcl.Diagnostics {
 	diags = append(diags, moreDiags...)
 
 	// find the require block
-	requireBlock := hcl_helpers.FindFirstChildBlock(modBlock, BlockTypeRequire)
+	requireBlock := hclhelpers.FindFirstChildBlock(modBlock, BlockTypeRequire)
 	if requireBlock == nil {
 		// was this the legacy 'requires' block?
-		requireBlock = hcl_helpers.FindFirstChildBlock(modBlock, BlockTypeLegacyRequires)
+		requireBlock = hclhelpers.FindFirstChildBlock(modBlock, BlockTypeLegacyRequires)
 	}
 	if requireBlock == nil {
 		// nothing else to populate
@@ -73,12 +73,12 @@ func (r *Require) initialise(modBlock *hcl.Block) hcl.Diagnostics {
 	}
 
 	// set our Ranges
-	r.DeclRange = hcl_helpers.BlockRange(requireBlock)
+	r.DeclRange = hclhelpers.BlockRange(requireBlock)
 	r.TypeRange = requireBlock.TypeRange
 
 	// build maps of plugin and mod blocks
-	pluginBlockMap := hcl_helpers.BlocksToMap(hcl_helpers.FindChildBlocks(requireBlock, BlockTypePlugin))
-	modBlockMap := hcl_helpers.BlocksToMap(hcl_helpers.FindChildBlocks(requireBlock, BlockTypeMod))
+	pluginBlockMap := hclhelpers.BlocksToMap(hclhelpers.FindChildBlocks(requireBlock, BlockTypePlugin))
+	modBlockMap := hclhelpers.BlocksToMap(hclhelpers.FindChildBlocks(requireBlock, BlockTypeMod))
 
 	if r.Steampipe != nil {
 		moreDiags := r.Steampipe.initialise(requireBlock)
