@@ -3,12 +3,12 @@ package var_config
 // github.com/hashicorp/terraform/configs/parser_config.go
 import (
 	"fmt"
-	"github.com/turbot/go-kit/hcl_helpers"
 	"unicode"
 
 	"github.com/hashicorp/hcl/v2"
 	"github.com/hashicorp/hcl/v2/gohcl"
 	"github.com/hashicorp/hcl/v2/hclsyntax"
+	"github.com/turbot/pipe-fittings/hclhelpers"
 	"github.com/turbot/steampipe/pkg/steampipeconfig/inputvars/typeexpr"
 	"github.com/zclconf/go-cty/cty"
 	"github.com/zclconf/go-cty/cty/convert"
@@ -36,7 +36,7 @@ type Variable struct {
 func DecodeVariableBlock(block *hcl.Block, content *hcl.BodyContent, override bool) (*Variable, hcl.Diagnostics) {
 	v := &Variable{
 		Name:      block.Labels[0],
-		DeclRange: hcl_helpers.BlockRange(block),
+		DeclRange: hclhelpers.BlockRange(block),
 	}
 	var diags hcl.Diagnostics
 
