@@ -7,7 +7,6 @@ import (
 	"strings"
 
 	"github.com/hashicorp/go-version"
-	"github.com/hashicorp/hcl/v2"
 	"github.com/turbot/go-kit/types"
 	typehelpers "github.com/turbot/go-kit/types"
 	"github.com/turbot/steampipe-plugin-sdk/v5/sperr"
@@ -15,6 +14,7 @@ import (
 	"github.com/turbot/steampipe/pkg/error_helpers"
 	"github.com/turbot/steampipe/pkg/filepaths"
 	"github.com/turbot/steampipe/pkg/ociinstaller"
+	"github.com/turbot/steampipe/pkg/ociinstaller/versionfile"
 	"github.com/turbot/steampipe/pkg/steampipeconfig/modconfig"
 	"github.com/turbot/steampipe/pkg/steampipeconfig/options"
 )
@@ -36,10 +36,8 @@ type SteampipeConfig struct {
 	TerminalOptions          *options.Terminal
 	GeneralOptions           *options.General
 	PluginOptions            *options.Plugin
-	// TODO remove this  in 0.22
-	// it is only needed due to conflicts with output name in terminal options
-	// https://github.com/turbot/steampipe/issues/2534
-	commandName string
+	// map of installed plugin versions, keyed by plugin image ref
+	PluginVersions map[string]*versionfile.InstalledVersion
 }
 
 func NewSteampipeConfig(commandName string) *SteampipeConfig {
@@ -47,7 +45,6 @@ func NewSteampipeConfig(commandName string) *SteampipeConfig {
 		Connections:      make(map[string]*modconfig.Connection),
 		Plugins:          make(map[string][]*modconfig.Plugin),
 		PluginsInstances: make(map[string]*modconfig.Plugin),
-		commandName:      commandName,
 	}
 }
 
@@ -91,9 +88,6 @@ func (c *SteampipeConfig) ConfigMap() map[string]interface{} {
 	if c.DashboardOptions != nil {
 		res.PopulateConfigMapForOptions(c.DashboardOptions)
 	}
-	if c.TerminalOptions != nil {
-		res.PopulateConfigMapForOptions(c.TerminalOptions)
-	}
 	if c.PluginOptions != nil {
 		res.PopulateConfigMapForOptions(c.PluginOptions)
 	}
@@ -105,14 +99,6 @@ func (c *SteampipeConfig) SetOptions(opts options.Options) (errorsAndWarnings *e
 	errorsAndWarnings = error_helpers.NewErrorsAndWarning(nil)
 
 	switch o := opts.(type) {
-	case *options.Connection:
-		// TODO: remove in 0.21 [https://github.com/turbot/steampipe/issues/3251]
-		errorsAndWarnings.AddWarning(deprecationWarning("connection options"))
-		if c.DefaultConnectionOptions == nil {
-			c.DefaultConnectionOptions = o
-		} else {
-			c.DefaultConnectionOptions.Merge(o)
-		}
 	case *options.Database:
 		if c.DatabaseOptions == nil {
 			c.DatabaseOptions = o
@@ -125,54 +111,22 @@ func (c *SteampipeConfig) SetOptions(opts options.Options) (errorsAndWarnings *e
 		} else {
 			c.DashboardOptions.Merge(o)
 		}
-	case *options.Terminal:
-		// TODO: remove in 0.21 [https://github.com/turbot/steampipe/issues/3251]
-		errorsAndWarnings.AddWarning(deprecationWarning("terminal options"))
-
-		// NOTE: ignore terminal options if current command is not query
-		// this is a short term workaround to handle the clashing 'output' argument
-		// this will be refactored
-		// TODO: remove in 0.21 [https://github.com/turbot/steampipe/issues/3251]
-		if c.commandName != constants.CmdNameQuery {
-			break
-		}
-		if c.TerminalOptions == nil {
-			c.TerminalOptions = o
-		} else {
-			c.TerminalOptions.Merge(o)
-		}
 	case *options.General:
 		if c.GeneralOptions == nil {
 			c.GeneralOptions = o
 		} else {
 			c.GeneralOptions.Merge(o)
 		}
-		// TODO: remove in 0.22 [https://github.com/turbot/steampipe/issues/3251]
-		if c.GeneralOptions.MaxParallel != nil {
-			errorsAndWarnings.AddWarning(deprecationWarning(fmt.Sprintf("'%s' in %s", constants.Bold("max_parallel"), constants.Bold("general options"))))
-		}
 	case *options.Plugin:
 		if c.PluginOptions == nil {
 			c.PluginOptions = o
 		} else {
 			c.PluginOptions.Merge(o)
 		}
-
-		// TODO: remove in 0.21 [https://github.com/turbot/steampipe/issues/3251]
-		if c.GeneralOptions.MaxParallel != nil {
-			errorsAndWarnings.AddWarning(deprecationWarning(fmt.Sprintf("'%s' in %s", constants.Bold("max_parallel"), constants.Bold("general options"))))
-		}
 	}
 	return errorsAndWarnings
 }
 
-func deprecationWarning(subject string) string {
-	if subject == "terminal options" {
-		return fmt.Sprintf("%s has been deprecated and will be removed in a future version of Steampipe.\nThese can now be set in a steampipe %s.", constants.Bold(subject), constants.Bold("workspace"))
-	}
-	return fmt.Sprintf("%s has been deprecated and will be removed in a future version of Steampipe.\nThis can now be set in a steampipe %s.", subject, constants.Bold("workspace"))
-}
-
 var defaultCacheEnabled = true
 var defaultTTL = 300
 
@@ -337,16 +291,28 @@ func (c *SteampipeConfig) ConnectionList() []*modconfig.Connection {
 }
 
 // add a plugin config to PluginsInstances and Plugins
-// NOTE: this returns an error if we alreayd have a config with the same label
-func (c *SteampipeConfig) addPlugin(plugin *modconfig.Plugin, block *hcl.Block) error {
+// NOTE: this returns an error if we already have a config with the same label
+func (c *SteampipeConfig) addPlugin(plugin *modconfig.Plugin) error {
 	if existingPlugin, exists := c.PluginsInstances[plugin.Instance]; exists {
 		return duplicatePluginError(existingPlugin, plugin)
 	}
+
 	// get the image ref to key the map
 	imageRef := plugin.Plugin
+
+	pluginVersion, ok := c.PluginVersions[imageRef]
+	if !ok {
+		// just log it
+		log.Printf("[WARN] addPlugin called for plugin '%s' which is not installed", imageRef)
+		return nil
+	}
+		//  populate the version from the plugin version file data
+		plugin.Version = pluginVersion.Version
+
 	// add to list of plugin configs for this image ref
 	c.Plugins[imageRef] = append(c.Plugins[imageRef], plugin)
 	c.PluginsInstances[plugin.Instance] = plugin
+
 	return nil
 }
 
@@ -358,7 +324,7 @@ func duplicatePluginError(existingPlugin, newPlugin *modconfig.Plugin) error {
 
 // ensure we have a plugin config struct for all plugins mentioned in connection config,
 // even if there is not an explicit HCL config for it
-// NOTE: this populates the  Plugin ans PluginInstance field of the connections
+// NOTE: this populates the  Plugin and PluginInstance field of the connections
 func (c *SteampipeConfig) initializePlugins() {
 	for _, connection := range c.Connections {
 		plugin, err := c.resolvePluginInstanceForConnection(connection)
@@ -430,17 +396,34 @@ func (c *SteampipeConfig) resolvePluginInstanceForConnection(connection *modconf
 
 	// resolve the image ref (this handles the special case of locally developed plugins in the plugins/local folder)
 	imageRef := modconfig.ResolvePluginImageRef(connection.PluginAlias)
+
+	// verify the plugin is installed - if not return nil
+	if _, ok := c.PluginVersions[imageRef]; !ok {
+		// tactical - check if the plugin binary exists
+		pluginBinaryPath := filepaths.PluginBinaryPath(imageRef, connection.PluginAlias)
+		if _, err := os.Stat(pluginBinaryPath); err != nil {
+			log.Printf("[INFO] plugin '%s' is not installed", imageRef)
+			return nil, nil
+		}
+
+		// so the plugin binary exists but it does not exist in the versions.json
+		// this is probably because it has been built locally - add a version entry with version set to 'local'
+		c.PluginVersions[imageRef] = &versionfile.InstalledVersion{
+			Version: "local",
+		}
+	}
+
+	// how many plugin instances are there for this image ref?
 	pluginsForImageRef := c.Plugins[imageRef]
 
-	// how many plugin instances are there?
 	switch len(pluginsForImageRef) {
 	case 0:
 		// there is no plugin instance for this connection - add an implicit plugin instance
 		p := modconfig.NewImplicitPlugin(connection, imageRef)
 
 		// now add to our map
-		// (NOTE: its ok to pass an empty HCL block - it is only used for the duplicate config error and we know we will not get that)
-		if err := c.addPlugin(p, &hcl.Block{}); err != nil {
+		if err := c.addPlugin(p); err != nil {
+			// log the error but do not return it - we
 			return nil, err
 		}
 		return p, nil
