@@ -162,7 +162,8 @@ func showNotificationsForCommand(cmd *cobra.Command, cmdArgs []string) bool {
 		IsPluginManagerCmd(cmd) ||
 		isServiceStopCmd(cmd) ||
 		IsBatchQueryCmd(cmd, cmdArgs) ||
-		isCompletionCmd(cmd))
+		isCompletionCmd(cmd) ||
+		isPluginListCmd(cmd))
 }
 
 func isServiceStopCmd(cmd *cobra.Command) bool {
@@ -180,3 +181,19 @@ func isPluginUpdateCmd(cmd *cobra.Command) bool {
 func IsBatchQueryCmd(cmd *cobra.Command, cmdArgs []string) bool {
 	return cmd.Name() == "query" && len(cmdArgs) > 0
 }
+func isPluginListCmd(cmd *cobra.Command) bool {
+	return cmd.Name() == "list" && cmd.Parent() != nil && cmd.Parent().Name() == "plugin"
+}
+
+func IsCheckCmd(cmd *cobra.Command) bool {
+	return cmd.Name() == "check"
+}
+
+func IsDashboardCmd(cmd *cobra.Command) bool {
+	return cmd.Name() == "dashboard"
+}
+
+func IsModCmd(cmd *cobra.Command) bool {
+	parent := cmd.Parent()
+	return parent.Name() == "mod"
+}
