@@ -1,10 +1,10 @@
 import "./utils/registerComponents";
 import Dashboard from "./components/dashboards/layout/Dashboard";
-import DashboardErrorModal from "./components/dashboards/DashboardErrorModal";
 import DashboardHeader from "./components/DashboardHeader";
 import DashboardList from "./components/DashboardList";
 import SnapshotHeader from "./components/SnapshotHeader";
 import useAnalytics from "./hooks/useAnalytics";
+import WorkspaceErrorModal from "./components/dashboards/WorkspaceErrorModal";
 import { DashboardProvider } from "./hooks/useDashboard";
 import { FullHeightThemeWrapper, useTheme } from "./hooks/useTheme";
 import { Route, Routes } from "react-router-dom";
@@ -15,10 +15,11 @@ const Dashboards = ({ analyticsContext, breakpointContext, themeContext }) => (
     analyticsContext={analyticsContext}
     breakpointContext={breakpointContext}
     themeContext={themeContext}
+    versionMismatchCheck={true}
   >
     <DashboardHeader />
     <SnapshotHeader />
-    <DashboardErrorModal />
+    <WorkspaceErrorModal />
     <DashboardList wrapperClassName="p-4 h-full overflow-y-auto" />
     <Dashboard />
   </DashboardProvider>
